@@ -4,7 +4,7 @@ module Rouge
   module Lexers
     class Groovy < RegexLexer
       title "Groovy"
-      desc 'The Groovy programming language (groovy.codehaus.org)'
+      desc 'The Groovy programming language (http://www.groovy-lang.org/)'
       tag 'groovy'
       filenames '*.groovy'
       mimetypes 'text/x-groovy'
@@ -53,14 +53,18 @@ module Rouge
         rule %r(//.*?$), Comment::Single
         rule %r(/[*].*?[*]/)m, Comment::Multiline
         rule /@\w[\w\d.]*/, Name::Decorator
-        rule /(class|interface)\b/,  Keyword::Declaration, :class
+        rule /(class|interface|trait)\b/,  Keyword::Declaration, :class
         rule /package\b/, Keyword::Namespace, :import
         rule /import\b/, Keyword::Namespace, :import
 
-        rule /"(\\\\|\\"|[^"])*"/, Str::Double
-        rule /'(\\\\|\\'|[^'])*'/, Str::Single
-        rule %r(\$/((?!/\$).)*/\$), Str
-        rule %r(/(\\\\|\\"|[^/])*/), Str
+        # TODO: highlight backslash escapes
+        rule /""".*?"""/m, Str::Double
+        rule /'''.*?'''/m, Str::Single
+
+        rule /"(\\.|\\\n|.)*?"/, Str::Double
+        rule /'(\\.|\\\n|.)*?'/, Str::Single
+        rule %r(\$/(\$.|.)*?/\$)m, Str
+        rule %r(/(\\.|\\\n|.)*?/), Str
         rule /'\\.'|'[^\\]'|'\\u[0-9a-f]{4}'/, Str::Char
         rule /(\.)([a-zA-Z_][a-zA-Z0-9_]*)/ do
           groups Operator, Name::Attribute
