@@ -2,6 +2,12 @@
 
 module Rouge
   module Lexers
+    # IMPORTANT NOTICE:
+    #
+    # Please do not copy this lexer and open a pull request
+    # for a new language. It will not get merged, you will
+    # be unhappy, and kittens will cry.
+    #
     class Javascript < RegexLexer
       title "JavaScript"
       desc "JavaScript, the browser scripting language"
@@ -33,7 +39,10 @@ module Rouge
           goto :regex
         end
 
-        rule /[{]/, Punctuation, :object
+        rule /[{]/ do
+          token Punctuation
+          goto :object
+        end
 
         rule //, Text, :pop!
       end
@@ -130,6 +139,11 @@ module Rouge
         rule /;/, Punctuation, :statement
         rule /[)\].]/, Punctuation
 
+        rule /`/ do
+          token Str::Double
+          push :template_string
+        end
+
         rule /[?]/ do
           token Punctuation
           push :ternary
@@ -161,10 +175,16 @@ module Rouge
         rule /[0-9]+/, Num::Integer
         rule /"(\\\\|\\"|[^"])*"/, Str::Double
         rule /'(\\\\|\\'|[^'])*'/, Str::Single
+        rule /:/, Punctuation
       end
 
       # braced parts that aren't object literals
       state :statement do
+        rule /case\b/ do
+          token Keyword
+          goto :expr_start
+        end
+
         rule /(#{id})(\s*)(:)/ do
           groups Name::Label, Text, Punctuation
         end
@@ -177,6 +197,12 @@ module Rouge
       # object literals
       state :object do
         mixin :comments_and_whitespace
+
+        rule /[{]/ do
+          token Punctuation
+          push
+        end
+
         rule /[}]/ do
           token Punctuation
           goto :statement
@@ -200,13 +226,26 @@ module Rouge
 
         mixin :root
       end
+
+      # template strings
+      state :template_string do
+        rule /\${/, Punctuation, :template_string_expr
+        rule /`/, Str::Double, :pop!
+        rule /(\\\\|\\[\$`]|[^\$`]|\$[^{])*/, Str::Double
+      end
+
+      state :template_string_expr do
+        rule /}/, Punctuation, :pop!
+        mixin :root
+      end
     end
 
     class JSON < RegexLexer
       desc "JavaScript Object Notation (json.org)"
       tag 'json'
       filenames '*.json'
-      mimetypes 'application/json', 'application/vnd.api+json'
+      mimetypes 'application/json', 'application/vnd.api+json',
+                'application/hal+json'
 
       # TODO: is this too much of a performance hit?  JSON is quite simple,
       # so I'd think this wouldn't be too bad, but for large documents this
